California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 015 - INCREASES FUNDING FOR PUBLIC SCHOOLS, COMMUNITY COLLEGES, AND LOCAL GOVERNMENT SERVICES BY CHANGING TAX ASSESSMENT OF COMMERCIAL AND INDUSTRIAL PROPERTY. INITIATIVE CONSTITUTIONAL... View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1384591 | MILLION VOTER PROJECT ACTION FUND - YES ON 15, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427119 | CALIFORNIA STATE CLUB ASSOCIATION AGAINST PROP 15: NO TO HIGHER PROPERTY TAXES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280428 | AGRICULTURAL COUNCIL OF CALIFORNIA COMMITTEE IN OPPOSITION TO PROP 15 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1403535 | CALIFORNIA CALLS EDUCATION FUND FOR SCHOOLS AND COMMUNITIES FIRST - YES ON 15 (NONPROFIT 501(C)(3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1404855 | LEAGUE OF WOMEN VOTERS OF CALIFORNIA SUPPORTING SCHOOLS AND COMMUNITIES FIRST - YES ON PROP 15 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1378703 | CALIFORNIA CALLS ACTION FUND FOR SCHOOLS AND COMMUNITIES FIRST - YES ON 15 (NONPROFIT 501 (C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428496 | SILICON VALLEY RISING ACTION ISSUES COMMITTEE, YES ON 15 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428950 | PICO CALIFORNIA ACTION FUND-YES ON 15, NO ON 20 (NONPROFIT 501 (C) (4) ) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405294 | PICO CALIFORNIA ACTION SUPPORTING SCHOOLS AND COMMUNITIES FIRST - YES ON 15, NO ON 20 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427286 | ALLIANCE OF CALIFORNIA'S FARMERS & RANCHERS AGAINST HIGHER PROPERTY TAXES, STOP PROP 15 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427752 | STOP THE TAX HIKES, NO ON 15 AND 19, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427634 | SILICON VALLEY RISING ACTION, YES ON PROP 15, NO ON PROP 22 (NONPROFIT 501 C4) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1403098 | YES ON 15 - SCHOOLS AND COMMUNITIES FIRST SPONSORED BY A COALITION OF LABOR GROUPS AND SOCIAL JUSTICE ORGANIZATIONS REPRESENTING FAMILIES, STUDENTS AND ESSENTIAL WORKERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1426041 | HIP COMMITTEE FOR SCHOOLS & COMMUNITIES FIRST | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1426379 | FAMILY FARMERS AGAINST PROP 15 - STOP HIGHER FOOD TAXES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431801 | ALTAMED HEALTH SERVICES CORPORATION (NONPROFIT 501(C)(3)) YES ON 15, 16, AND 17 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424664 | STOP HIGHER TAXES COMMITTEE, SPONSORED BY FAMILY BUSINESS ASSOCIATION OF CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1395636 | SPEAK UP - YES ON 15 AND 16/ SUPPORTING KOZIATEK AND ORTIZ-FRANKLIN FOR SCHOOL BOARD 2020 (NONPROFIT 501(C(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1432339 | CALCIMA ISSUES PAC, NO ON PROPOSITION 15, SPONSORED BY CA CONSTRUCTION & INDUSTRIAL MATERIALS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1433352 | ENOUGH IS ENOUGH, NO NEW TAXES! | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1432182 | ADVANCEMENT PROJECT CALIFORNIA (NONPROFIT 501(C)(3)) YES ON 15 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1433572 | CALIFORNIA DEMOCRATIC SOCIALISTS OF AMERICA (DSA) POLITICAL ACTION COMMITTEE IN SUPPORT OF PROP 15 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
931447 | PROTECT PROP. 13, NO ON 15, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1403027 | NO ON PROP 15 - STOP HIGHER PROPERTY TAXES AND SAVE PROP 13 - A COALITION OF CALIFORNIA HOMEOWNERS, TAXPAYERS, AND BUSINESSES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1423734 | CALIFORNIA FUELS & CONVENIENCE ALLIANCE (NON-PROFIT 501 (C) (6), NO ON AG-19-008 - THE SCHOOLS AND LOCAL COMMUNITIES FUNDING ACT OF 2020 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405857 | CHAN ZUCKERBERG INITIATIVE ADVOCACY - YES ON 15 (NONPROFIT 501(C)(4)) | SUPPORT